      SUBROUTINE FNDNEW(NOWMTH,NOWYER,MCHMTH,MCHYER,IERASE)
C     RENBR(/TESTS IF MONTHLY TAPE STILL EXISTS)
C
C     DONALD BARTH, HARVARD BUSINESS SCHOOL
C
C     THIS ROUTINE DEPENDS UPON THE RECYCLING SCHEDULE FOR
C     THE MONTHLY SAVE TAPES OF THE PUBLIC DISK STRUCTURES.
C     THIS IS A NON-FUNCTIONAL VERSION OF THIS ROUTINE.
C     IT INDICATES THAT ALL TAPE SETS ARE STILL AVAILABLE.
C
C     FOLLOWING ARGUMENTS ARE RETURNED UNCHANGED
C     NOWMTH = CURRENT MONTH, 1 = JANUARY
C     NOWYER = CURRENT YEAR, RIGHT 2 DIGITS
C     MCHMTH = MONTH OF DATE TO BE SEARCHED, 1 = JANUARY
C     MCHYER = YEAR OF DATE TO BE SEARCHED, RIGHT 2 DIGITS
C
C     NOTE THAT AFTER YEAR AT YEAR 2000, NOWYER AND MCHYER
C     BECOME RIGHT 2 DIGITS PLUS 100.
C
C     THE FOLLOWING ARGUMENT WOULD BE RETURNED CHANGED
C     BY A FUNCTIONAL VERSION OF THIS ROUTINE.
C     THE ORIGINAL VALUE OF THIS ARGUMENT IS IGNORED.
C     IERASE = 0, THE TAPE STILL EXISTS
C            = 1, THE TAPE HAS BEEN ERASED
C
      RETURN
      END

